@@ -1,14 +1,4 @@
-# Tests for label functions (add_auto_labels and apply_labels_from_dictionary)
-
-# Helper function to get unlabeled trial data
-get_unlabeled_trial <- function() {
-  data <- gtsummary::trial
-  # Clear any existing label attributes
-  for (col in names(data)) {
-    attr(data[[col]], "label") <- NULL
-  }
-  data
-}
+# Tests for add_auto_labels()
 
 test_that("add_auto_labels() works with tbl_summary", {
   skip_if_not_installed("gtsummary")
@@ -70,7 +60,8 @@ test_that("add_auto_labels() preserves manual label overrides", {
     add_auto_labels(dictionary = my_dict)
 
   expect_s3_class(tbl, "gtsummary")
-  # Manual label should be preserved (this test may need updating based on new behavior)
+  # Manual label should be preserved
+  # (may need updating based on new behavior)
   age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
   expect_equal(age_label, "Manual Override")
 })
@@ -104,16 +95,10 @@ test_that("add_auto_labels() searches environment for dictionary", {
     "age", "Age from Environment"
   )
 
-  # Should find dictionary automatically
-  # Reset the message flag for this test
-  options(sumExtras.dictionary_message_shown = NULL)
-
-  expect_message(
-    tbl <- get_unlabeled_trial() |>
-      gtsummary::tbl_summary(include = age) |>
-      add_auto_labels(),
-    "Auto-labeling from 'dictionary' object in your environment"
-  )
+  # Should find dictionary automatically (silently)
+  tbl <- get_unlabeled_trial() |>
+    gtsummary::tbl_summary(include = age) |>
+    add_auto_labels()
 
   age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
   expect_equal(age_label, "Age from Environment")
@@ -129,7 +114,7 @@ test_that("add_auto_labels() reads label attributes from data", {
 
   tbl <- labeled_data |>
     gtsummary::tbl_summary(include = c(age, marker)) |>
-    add_auto_labels()  # No dictionary provided
+    add_auto_labels() # No dictionary provided
 
   age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
   marker_label <- tbl$table_body$label[tbl$table_body$variable == "marker"][1]
@@ -138,42 +123,13 @@ test_that("add_auto_labels() reads label attributes from data", {
   expect_equal(marker_label, "Marker from Attribute")
 })
 
-test_that("add_auto_labels() respects options(sumExtras.preferDictionary = TRUE)", {
+test_that("add_auto_labels() attributes win over dictionary", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
-  # Set option
-  old_opt <- getOption("sumExtras.preferDictionary")
-  on.exit(options(sumExtras.preferDictionary = old_opt), add = TRUE)
-  options(sumExtras.preferDictionary = TRUE)
-
-  # Create data with attribute
-  labeled_data <- gtsummary::trial
-  attr(labeled_data$age, "label") <- "Age from Attribute"
-
-  # Create dictionary
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age from Dictionary"
-  )
-
-  tbl <- labeled_data |>
-    gtsummary::tbl_summary(include = age) |>
-    add_auto_labels(dictionary = my_dict)
-
-  age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
-  # Dictionary should win
-  expect_equal(age_label, "Age from Dictionary")
-})
-
-test_that("add_auto_labels() respects options(sumExtras.preferDictionary = FALSE)", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  # Set option
-  old_opt <- getOption("sumExtras.preferDictionary")
-  on.exit(options(sumExtras.preferDictionary = old_opt), add = TRUE)
-  options(sumExtras.preferDictionary = FALSE)
+  old_opt <- getOption("sumExtras.prefer_dictionary")
+  on.exit(options(sumExtras.prefer_dictionary = old_opt), add = TRUE)
+  options(sumExtras.prefer_dictionary = FALSE)
 
   # Create data with attribute
   labeled_data <- gtsummary::trial
@@ -271,7 +227,7 @@ test_that("add_auto_labels() preserves manual labels from tbl_svysummary", {
   expect_equal(age_label, "Manual Override")
 })
 
-test_that("add_auto_labels() handles no dictionary and no attributes gracefully", {
+test_that("add_auto_labels() handles no dict and no attrs", {
   skip_if_not_installed("gtsummary")
 
   # No dictionary, no attributes - should just work without errors
@@ -285,130 +241,13 @@ test_that("add_auto_labels() handles no dictionary and no attributes gracefully"
   expect_true(!is.na(age_label))
 })
 
-# TESTS FOR apply_labels_from_dictionary()
-
-test_that("apply_labels_from_dictionary() sets label attributes", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age at Enrollment",
-    "marker", "Marker Level"
-  )
-
-  labeled_data <- gtsummary::trial |>
-    apply_labels_from_dictionary(my_dict)
-
-  expect_equal(attr(labeled_data$age, "label"), "Age at Enrollment")
-  expect_equal(attr(labeled_data$marker, "label"), "Marker Level")
-})
-
-test_that("apply_labels_from_dictionary() overwrites existing labels by default", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  # Set existing label
-  data_with_label <- gtsummary::trial
-  attr(data_with_label$age, "label") <- "Existing Label"
-
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "New Label"
-  )
-
-  labeled_data <- data_with_label |>
-    apply_labels_from_dictionary(my_dict)
-
-  expect_equal(attr(labeled_data$age, "label"), "New Label")
-})
-
-test_that("apply_labels_from_dictionary() preserves existing labels when overwrite = FALSE", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  # Set existing label on unlabeled data
-  data_with_label <- get_unlabeled_trial()
-  attr(data_with_label$age, "label") <- "Existing Label"
-
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "New Label",
-    "marker", "Marker Label"
-  )
-
-  labeled_data <- data_with_label |>
-    apply_labels_from_dictionary(my_dict, overwrite = FALSE)
-
-  # age should keep existing label
-  expect_equal(attr(labeled_data$age, "label"), "Existing Label")
-  # marker should get new label (had none before)
-  expect_equal(attr(labeled_data$marker, "label"), "Marker Label")
-})
-
-test_that("apply_labels_from_dictionary() ignores dictionary entries for missing variables", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age",
-    "nonexistent_var", "This doesn't exist"
-  )
-
-  # Should not error
-  labeled_data <- gtsummary::trial |>
-    apply_labels_from_dictionary(my_dict)
-
-  expect_equal(attr(labeled_data$age, "label"), "Age")
-  expect_false("nonexistent_var" %in% names(labeled_data))
-})
-
-test_that("apply_labels_from_dictionary() errors with non-data.frame input", {
-  skip_if_not_installed("tibble")
-
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age"
-  )
-
-  expect_error(
-    apply_labels_from_dictionary("not a data frame", my_dict),
-    "must be a data frame"
-  )
-})
-
-test_that("apply_labels_from_dictionary() errors with missing dictionary", {
-  skip_if_not_installed("gtsummary")
-
-  expect_error(
-    apply_labels_from_dictionary(gtsummary::trial),
-    "dictionary.*required"
-  )
-})
-
-test_that("apply_labels_from_dictionary() errors with invalid dictionary columns", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  bad_dict <- tibble::tribble(
-    ~VarName, ~Label,
-    "age", "Age"
-  )
-
-  expect_error(
-    apply_labels_from_dictionary(gtsummary::trial, bad_dict),
-    "missing required columns"
-  )
-})
-
 # EDGE CASE TESTS
 
 test_that("add_auto_labels() handles empty strings in attributes", {
   skip_if_not_installed("gtsummary")
 
   labeled_data <- gtsummary::trial
-  attr(labeled_data$age, "label") <- ""  # Empty string
+  attr(labeled_data$age, "label") <- "" # Empty string
 
   tbl <- labeled_data |>
     gtsummary::tbl_summary(include = age) |>
@@ -439,29 +278,13 @@ test_that("add_auto_labels() handles duplicate dictionary entries", {
   # Behavior with duplicates is defined by left_join (uses first match)
 })
 
-test_that("apply_labels_from_dictionary() handles invalid overwrite parameter", {
+test_that("add_auto_labels() dict + attributes correct priority", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age"
-  )
-
-  expect_error(
-    apply_labels_from_dictionary(gtsummary::trial, my_dict, overwrite = "yes"),
-    "must be a single logical value"
-  )
-
-  expect_error(
-    apply_labels_from_dictionary(gtsummary::trial, my_dict, overwrite = c(TRUE, FALSE)),
-    "must be a single logical value"
-  )
-})
-
-test_that("add_auto_labels() with both dictionary and attributes uses correct priority", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
+  old_opt <- getOption("sumExtras.prefer_dictionary")
+  on.exit(options(sumExtras.prefer_dictionary = old_opt), add = TRUE)
+  options(sumExtras.prefer_dictionary = FALSE)
 
   # Default behavior (prefer attributes)
   labeled_data <- get_unlabeled_trial()
@@ -482,7 +305,7 @@ test_that("add_auto_labels() with both dictionary and attributes uses correct pr
   marker_label <- tbl$table_body$label[tbl$table_body$variable == "marker"][1]
   grade_label <- tbl$table_body$label[tbl$table_body$variable == "grade"][1]
 
-  # age has both - attribute wins (default preferDictionary = FALSE)
+  # age has both - attribute wins
   expect_equal(age_label, "Attribute Label")
   # marker has only attribute
   expect_equal(marker_label, "Marker Attribute")
@@ -520,38 +343,27 @@ test_that("add_auto_labels() handles unicode and emoji in labels", {
 # COMPREHENSIVE TESTS FOR DICTIONARY AUTO-DISCOVERY
 # ==============================================================================
 
-test_that("add_auto_labels() shows message only once per session for auto-discovery", {
+test_that("add_auto_labels() auto-discovery is silent", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
-  # Reset message flag
-  options(sumExtras.dictionary_message_shown = NULL)
-
   dictionary <- tibble::tribble(
     ~Variable, ~Description,
     "age", "Age Label"
   )
 
-  # First call should show message
-  expect_message(
-    get_unlabeled_trial() |>
-      gtsummary::tbl_summary(include = age) |>
-      add_auto_labels(),
-    "Auto-labeling from 'dictionary'"
-  )
-
-  # Second call should NOT show message
+  # Should be silent (no message)
   expect_no_message(
-    get_unlabeled_trial() |>
+    tbl <- get_unlabeled_trial() |>
       gtsummary::tbl_summary(include = age) |>
       add_auto_labels()
   )
 
-  # Clean up
-  options(sumExtras.dictionary_message_shown = NULL)
+  age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
+  expect_equal(age_label, "Age Label")
 })
 
-test_that("add_auto_labels() auto-discovery works when dictionary has extra variables", {
+test_that("add_auto_labels() auto-discovery with extra dict vars", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
@@ -566,7 +378,6 @@ test_that("add_auto_labels() auto-discovery works when dictionary has extra vari
     "death", "Patient Died"
   )
 
-  options(sumExtras.dictionary_message_shown = NULL)
 
   # Only include age - should still work
   tbl <- get_unlabeled_trial() |>
@@ -575,11 +386,9 @@ test_that("add_auto_labels() auto-discovery works when dictionary has extra vari
 
   age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
   expect_equal(age_label, "Age at Baseline")
-
-  options(sumExtras.dictionary_message_shown = NULL)
 })
 
-test_that("add_auto_labels() handles dictionary with no matching variables gracefully", {
+test_that("add_auto_labels() handles dict with no matching vars", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
@@ -590,7 +399,6 @@ test_that("add_auto_labels() handles dictionary with no matching variables grace
     "bar", "Bar Variable"
   )
 
-  options(sumExtras.dictionary_message_shown = NULL)
 
   # Should work without error
   tbl <- get_unlabeled_trial() |>
@@ -599,21 +407,16 @@ test_that("add_auto_labels() handles dictionary with no matching variables grace
 
   expect_s3_class(tbl, "gtsummary")
   # Label should remain as default (not from dictionary)
-
-  options(sumExtras.dictionary_message_shown = NULL)
 })
 
 # ==============================================================================
 # COMPREHENSIVE TESTS FOR LABEL PRIORITY LOGIC
 # ==============================================================================
 
-test_that("add_auto_labels() priority: manual > attribute > dictionary (default)", {
+test_that("add_auto_labels() priority: manual > attr > dict", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
-  # Reset to default
-  options(sumExtras.preferDictionary = FALSE)
-
   # Create data with attributes for age and marker
   labeled_data <- get_unlabeled_trial()
   attr(labeled_data$age, "label") <- "Age from Attribute"
@@ -638,7 +441,9 @@ test_that("add_auto_labels() priority: manual > attribute > dictionary (default)
   age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
   marker_label <- tbl$table_body$label[tbl$table_body$variable == "marker"][1]
   grade_label <- tbl$table_body$label[tbl$table_body$variable == "grade"][1]
-  response_label <- tbl$table_body$label[tbl$table_body$variable == "response"][1]
+  response_label <- tbl$table_body$label[
+    tbl$table_body$variable == "response"
+  ][1]
 
   # age: manual override wins
   expect_equal(age_label, "Age Manual Override")
@@ -650,32 +455,24 @@ test_that("add_auto_labels() priority: manual > attribute > dictionary (default)
   expect_equal(response_label, "Response from Dictionary")
 })
 
-test_that("add_auto_labels() priority: manual > dictionary > attribute (preferDictionary = TRUE)", {
+test_that("add_auto_labels() dict is fallback when no attribute", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
-  # Set preference
-  old_opt <- getOption("sumExtras.preferDictionary")
-  on.exit(options(sumExtras.preferDictionary = old_opt), add = TRUE)
-  options(sumExtras.preferDictionary = TRUE)
-
-  # Create data with attributes
+  # Create data with attribute only for marker
   labeled_data <- get_unlabeled_trial()
-  attr(labeled_data$age, "label") <- "Age from Attribute"
   attr(labeled_data$marker, "label") <- "Marker from Attribute"
 
-  # Dictionary
+  # Dictionary has age and grade
   my_dict <- tibble::tribble(
     ~Variable, ~Description,
     "age", "Age from Dictionary",
     "grade", "Grade from Dictionary"
   )
 
-  # Manual override for age
   tbl <- labeled_data |>
     gtsummary::tbl_summary(
-      include = c(age, marker, grade),
-      label = list(age ~ "Age Manual Override")
+      include = c(age, marker, grade)
     ) |>
     add_auto_labels(dictionary = my_dict)
 
@@ -683,11 +480,11 @@ test_that("add_auto_labels() priority: manual > dictionary > attribute (preferDi
   marker_label <- tbl$table_body$label[tbl$table_body$variable == "marker"][1]
   grade_label <- tbl$table_body$label[tbl$table_body$variable == "grade"][1]
 
-  # age: manual override still wins
-  expect_equal(age_label, "Age Manual Override")
-  # marker: only attribute (no dictionary entry)
+  # age: dictionary (no attribute)
+  expect_equal(age_label, "Age from Dictionary")
+  # marker: attribute (no dictionary entry)
   expect_equal(marker_label, "Marker from Attribute")
-  # grade: only dictionary
+  # grade: dictionary (no attribute)
   expect_equal(grade_label, "Grade from Dictionary")
 })
 
@@ -743,7 +540,7 @@ test_that("add_auto_labels() errors informatively with non-gtsummary input", {
 
   expect_error(
     add_auto_labels(data.frame(x = 1:5)),
-    "Create a gtsummary table"
+    "Create a table"
   )
 })
 
@@ -765,7 +562,7 @@ test_that("add_auto_labels() errors informatively with invalid dictionary", {
   )
 })
 
-test_that("add_auto_labels() errors informatively with missing dictionary columns", {
+test_that("add_auto_labels() errors with missing dict columns", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
@@ -785,10 +582,10 @@ test_that("add_auto_labels() errors informatively with missing dictionary column
 
   expect_error(
     add_auto_labels(tbl, dictionary = bad_dict1),
-    "Missing column.*Variable"
+    "Missing column.*variable"
   )
 
-  # Missing Description column
+  # Missing description column (Variable is present, Label is not description)
   bad_dict2 <- tibble::tribble(
     ~Variable, ~Label,
     "age", "Age"
@@ -796,7 +593,7 @@ test_that("add_auto_labels() errors informatively with missing dictionary column
 
   expect_error(
     add_auto_labels(tbl, dictionary = bad_dict2),
-    "Missing column.*Description"
+    "Missing column.*description"
   )
 
   # Missing both columns
@@ -807,58 +604,7 @@ test_that("add_auto_labels() errors informatively with missing dictionary column
 
   expect_error(
     add_auto_labels(tbl, dictionary = bad_dict3),
-    "Missing column.*Variable.*Description"
-  )
-})
-
-test_that("apply_labels_from_dictionary() errors have correct class and messages", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age"
-  )
-
-  # Non-data.frame data
-  expect_error(
-    apply_labels_from_dictionary("not a df", my_dict),
-    class = "apply_labels_invalid_data"
-  )
-
-  # Missing dictionary
-  expect_error(
-    apply_labels_from_dictionary(gtsummary::trial),
-    class = "apply_labels_missing_dictionary"
-  )
-
-  # NULL dictionary
-  expect_error(
-    apply_labels_from_dictionary(gtsummary::trial, dictionary = NULL),
-    class = "apply_labels_missing_dictionary"
-  )
-
-  # Non-data.frame dictionary
-  expect_error(
-    apply_labels_from_dictionary(gtsummary::trial, dictionary = "not a df"),
-    class = "apply_labels_invalid_dictionary_type"
-  )
-
-  # Missing columns
-  bad_dict <- tibble::tribble(
-    ~Var, ~Desc,
-    "age", "Age"
-  )
-
-  expect_error(
-    apply_labels_from_dictionary(gtsummary::trial, bad_dict),
-    class = "apply_labels_missing_columns"
-  )
-
-  # Invalid overwrite
-  expect_error(
-    apply_labels_from_dictionary(gtsummary::trial, my_dict, overwrite = "yes"),
-    class = "apply_labels_invalid_overwrite"
+    "Missing column.*variable.*description"
   )
 })
 
@@ -910,49 +656,14 @@ test_that("add_auto_labels() handles data with all missing values", {
   expect_s3_class(tbl, "gtsummary")
 })
 
-test_that("apply_labels_from_dictionary() handles data with zero rows", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  empty_data <- gtsummary::trial[0, ]
-
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age",
-    "marker", "Marker"
-  )
-
-  labeled <- apply_labels_from_dictionary(empty_data, my_dict)
-
-  expect_equal(nrow(labeled), 0)
-  expect_equal(attr(labeled$age, "label"), "Age")
-  expect_equal(attr(labeled$marker, "label"), "Marker")
-})
-
-test_that("apply_labels_from_dictionary() handles data with single row", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  single_row <- gtsummary::trial[1, ]
-
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Patient Age",
-    "marker", "Biomarker"
-  )
-
-  labeled <- apply_labels_from_dictionary(single_row, my_dict)
-
-  expect_equal(nrow(labeled), 1)
-  expect_equal(attr(labeled$age, "label"), "Patient Age")
-  expect_equal(attr(labeled$marker, "label"), "Biomarker")
-})
-
 test_that("add_auto_labels() handles very long label strings", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
-  long_label <- paste(rep("Very long description that goes on and on", 10), collapse = " ")
+  long_label <- paste(
+    rep("Very long description that goes on and on", 10),
+    collapse = " "
+  )
 
   long_dict <- tibble::tribble(
     ~Variable, ~Description,
@@ -967,39 +678,13 @@ test_that("add_auto_labels() handles very long label strings", {
   expect_equal(age_label, long_label)
 })
 
-test_that("apply_labels_from_dictionary() preserves data structure and values", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  original_data <- get_unlabeled_trial()
-
-  my_dict <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age",
-    "marker", "Marker"
-  )
-
-  labeled_data <- apply_labels_from_dictionary(original_data, my_dict)
-
-  # Data values should be unchanged (ignore label attributes for comparison)
-  expect_equal(as.numeric(labeled_data$age), as.numeric(original_data$age))
-  expect_equal(as.numeric(labeled_data$marker), as.numeric(original_data$marker))
-  expect_equal(nrow(labeled_data), nrow(original_data))
-  expect_equal(ncol(labeled_data), ncol(original_data))
-  expect_equal(names(labeled_data), names(original_data))
-
-  # Labels should be set
-  expect_equal(attr(labeled_data$age, "label"), "Age")
-  expect_equal(attr(labeled_data$marker, "label"), "Marker")
-})
-
 # ==============================================================================
 # INTEGRATION TESTS - VIGNETTE SCENARIOS
 # ==============================================================================
 
-context("Integration Tests - Vignette Workflows")
+# Integration Tests - Vignette Workflows
 
-test_that("Vignette scenario: dictionary passed explicitly to add_auto_labels()", {
+test_that("Vignette scenario: explicit dict to add_auto_labels()", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
@@ -1032,7 +717,6 @@ test_that("Vignette scenario: automatic dictionary discovery", {
   skip_if_not_installed("tibble")
 
   # Reset message flag
-  options(sumExtras.dictionary_message_shown = NULL)
 
   dictionary <- tibble::tribble(
     ~Variable, ~Description,
@@ -1051,13 +735,13 @@ test_that("Vignette scenario: automatic dictionary discovery", {
 
   age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
   stage_label <- tbl$table_body$label[tbl$table_body$variable == "stage"][1]
-  response_label <- tbl$table_body$label[tbl$table_body$variable == "response"][1]
+  response_label <- tbl$table_body$label[
+    tbl$table_body$variable == "response"
+  ][1]
 
   expect_equal(age_label, "Age at Enrollment (years)")
   expect_equal(stage_label, "T Stage")
   expect_equal(response_label, "Tumor Response")
-
-  options(sumExtras.dictionary_message_shown = NULL)
 })
 
 test_that("Vignette scenario: working with pre-labeled data", {
@@ -1108,50 +792,13 @@ test_that("Vignette scenario: manual overrides always win", {
   expect_equal(marker_label, "Marker Level (ng/mL)")
 })
 
-test_that("Vignette scenario: apply_labels_from_dictionary() then use in gtsummary", {
+test_that("Vignette scenario: attributes always win over dictionary", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
-  my_dictionary <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age at Enrollment (years)",
-    "marker", "Marker Level (ng/mL)",
-    "trt", "Treatment Group",
-    "grade", "Tumor Grade"
-  )
-
-  trial_labeled <- get_unlabeled_trial() |>
-    apply_labels_from_dictionary(my_dictionary)
-
-  # Verify attributes were set
-  expect_equal(attr(trial_labeled$age, "label"), "Age at Enrollment (years)")
-  expect_equal(attr(trial_labeled$marker, "label"), "Marker Level (ng/mL)")
-  expect_equal(attr(trial_labeled$trt, "label"), "Treatment Group")
-
-  # Use in gtsummary
-  tbl <- trial_labeled |>
-    gtsummary::tbl_summary(by = trt, include = c(age, marker, grade)) |>
-    add_auto_labels()
-
-  age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
-  marker_label <- tbl$table_body$label[tbl$table_body$variable == "marker"][1]
-  grade_label <- tbl$table_body$label[tbl$table_body$variable == "grade"][1]
-
-  expect_equal(age_label, "Age at Enrollment (years)")
-  expect_equal(marker_label, "Marker Level (ng/mL)")
-  expect_equal(grade_label, "Tumor Grade")
-})
-
-test_that("Vignette scenario: controlling label priority with options", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  # Save old option
-  old_opt <- getOption("sumExtras.preferDictionary")
-  on.exit(options(sumExtras.preferDictionary = old_opt), add = TRUE)
-
-  # Test with preferDictionary = FALSE (default)
-  options(sumExtras.preferDictionary = FALSE)
+  old_opt <- getOption("sumExtras.prefer_dictionary")
+  on.exit(options(sumExtras.prefer_dictionary = old_opt), add = TRUE)
+  options(sumExtras.prefer_dictionary = FALSE)
 
   trial_both <- get_unlabeled_trial()
   attr(trial_both$age, "label") <- "Age from Attribute"
@@ -1161,101 +808,12 @@ test_that("Vignette scenario: controlling label priority with options", {
     "age", "Age from Dictionary"
   )
 
-  tbl1 <- trial_both |>
+  tbl <- trial_both |>
     gtsummary::tbl_summary(by = trt, include = age) |>
     add_auto_labels(dictionary = dictionary_conflict)
 
-  age_label1 <- tbl1$table_body$label[tbl1$table_body$variable == "age"][1]
-  expect_equal(age_label1, "Age from Attribute")
-
-  # Test with preferDictionary = TRUE
-  options(sumExtras.preferDictionary = TRUE)
-
-  tbl2 <- trial_both |>
-    gtsummary::tbl_summary(by = trt, include = age) |>
-    add_auto_labels(dictionary = dictionary_conflict)
-
-  age_label2 <- tbl2$table_body$label[tbl2$table_body$variable == "age"][1]
-  expect_equal(age_label2, "Age from Dictionary")
-})
-
-test_that("Vignette scenario: cross-package workflow with apply_labels_from_dictionary()", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-
-  my_dictionary <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age at Enrollment (years)",
-    "marker", "Marker Level (ng/mL)",
-    "trt", "Treatment Group",
-    "grade", "Tumor Grade",
-    "stage", "T Stage"
-  )
-
-  # Apply to data once
-  trial_final <- get_unlabeled_trial() |>
-    apply_labels_from_dictionary(my_dictionary)
-
-  # Verify labels are set as attributes
-  expect_equal(attr(trial_final$age, "label"), "Age at Enrollment (years)")
-  expect_equal(attr(trial_final$marker, "label"), "Marker Level (ng/mL)")
-  expect_equal(attr(trial_final$trt, "label"), "Treatment Group")
-  expect_equal(attr(trial_final$grade, "label"), "Tumor Grade")
-  expect_equal(attr(trial_final$stage, "label"), "T Stage")
-
-  # Use in gtsummary table
-  tbl <- trial_final |>
-    gtsummary::tbl_summary(
-      by = trt,
-      include = c(age, marker, grade, stage)
-    ) |>
-    add_auto_labels()
-
-  expect_s3_class(tbl, "gtsummary")
-
-  # Verify labels in table
   age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
-  marker_label <- tbl$table_body$label[tbl$table_body$variable == "marker"][1]
-  grade_label <- tbl$table_body$label[tbl$table_body$variable == "grade"][1]
-  stage_label <- tbl$table_body$label[tbl$table_body$variable == "stage"][1]
-
-  expect_equal(age_label, "Age at Enrollment (years)")
-  expect_equal(marker_label, "Marker Level (ng/mL)")
-  expect_equal(grade_label, "Tumor Grade")
-  expect_equal(stage_label, "T Stage")
-})
-
-test_that("Vignette scenario: combining with dplyr operations preserves labels", {
-  skip_if_not_installed("gtsummary")
-  skip_if_not_installed("tibble")
-  skip_if_not_installed("dplyr")
-
-  dictionary <- tibble::tribble(
-    ~Variable, ~Description,
-    "age", "Age at Enrollment (years)",
-    "marker", "Marker Level (ng/mL)",
-    "trt", "Treatment Group"
-  )
-
-  trial_labeled <- get_unlabeled_trial() |>
-    apply_labels_from_dictionary(dictionary)
-
-  # Perform dplyr operations
-  trial_subset <- trial_labeled |>
-    dplyr::filter(stage %in% c("T1", "T2")) |>
-    dplyr::select(age, marker, trt)
-
-  # Labels should survive
-  expect_equal(attr(trial_subset$age, "label"), "Age at Enrollment (years)")
-  expect_equal(attr(trial_subset$marker, "label"), "Marker Level (ng/mL)")
-  expect_equal(attr(trial_subset$trt, "label"), "Treatment Group")
-
-  # Use in table
-  tbl <- trial_subset |>
-    gtsummary::tbl_summary(by = trt) |>
-    add_auto_labels()
-
-  expect_s3_class(tbl, "gtsummary")
+  expect_equal(age_label, "Age from Attribute")
 })
 
 # ==============================================================================
@@ -1292,34 +850,150 @@ test_that("add_auto_labels() handles large dictionaries efficiently", {
   expect_s3_class(tbl, "gtsummary")
 })
 
-test_that("apply_labels_from_dictionary() handles wide data (many columns)", {
+# ==============================================================================
+# PREFER DICTIONARY OPTION TESTS
+# ==============================================================================
+
+test_that("prefer_dictionary: dictionary wins over attributes when TRUE", {
   skip_if_not_installed("gtsummary")
   skip_if_not_installed("tibble")
 
-  # Create data with many columns
-  wide_data <- gtsummary::trial[, c("age", "marker", "trt", "grade", "stage", "response", "death")]
+  old_opt <- getOption("sumExtras.prefer_dictionary")
+  on.exit(options(sumExtras.prefer_dictionary = old_opt), add = TRUE)
+  options(sumExtras.prefer_dictionary = TRUE)
 
-  wide_dict <- tibble::tribble(
+  labeled_data <- get_unlabeled_trial()
+  attr(labeled_data$age, "label") <- "Age from Attribute"
+
+  my_dict <- tibble::tribble(
     ~Variable, ~Description,
-    "age", "Age",
-    "marker", "Marker",
-    "trt", "Treatment",
-    "grade", "Grade",
-    "stage", "Stage",
-    "response", "Response",
-    "death", "Death"
+    "age", "Age from Dictionary"
   )
 
-  labeled <- apply_labels_from_dictionary(wide_data, wide_dict)
+  tbl <- labeled_data |>
+    gtsummary::tbl_summary(include = age) |>
+    add_auto_labels(dictionary = my_dict)
 
-  # All should be labeled
-  expect_equal(attr(labeled$age, "label"), "Age")
-  expect_equal(attr(labeled$marker, "label"), "Marker")
-  expect_equal(attr(labeled$trt, "label"), "Treatment")
-  expect_equal(attr(labeled$grade, "label"), "Grade")
-  expect_equal(attr(labeled$stage, "label"), "Stage")
-  expect_equal(attr(labeled$response, "label"), "Response")
-  expect_equal(attr(labeled$death, "label"), "Death")
+  age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
+  expect_equal(age_label, "Age from Dictionary")
+})
+
+test_that("prefer_dictionary: attributes win when option is FALSE", {
+  skip_if_not_installed("gtsummary")
+  skip_if_not_installed("tibble")
+
+  old_opt <- getOption("sumExtras.prefer_dictionary")
+  on.exit(options(sumExtras.prefer_dictionary = old_opt), add = TRUE)
+  options(sumExtras.prefer_dictionary = FALSE)
+
+  labeled_data <- get_unlabeled_trial()
+  attr(labeled_data$age, "label") <- "Age from Attribute"
+
+  my_dict <- tibble::tribble(
+    ~Variable, ~Description,
+    "age", "Age from Dictionary"
+  )
+
+  tbl <- labeled_data |>
+    gtsummary::tbl_summary(include = age) |>
+    add_auto_labels(dictionary = my_dict)
+
+  age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
+  expect_equal(age_label, "Age from Attribute")
+})
+
+test_that("prefer_dictionary: attributes win when option is unset", {
+  skip_if_not_installed("gtsummary")
+  skip_if_not_installed("tibble")
+
+  old_opt <- getOption("sumExtras.prefer_dictionary")
+  on.exit(options(sumExtras.prefer_dictionary = old_opt), add = TRUE)
+  options(sumExtras.prefer_dictionary = NULL)
+
+  labeled_data <- get_unlabeled_trial()
+  attr(labeled_data$age, "label") <- "Age from Attribute"
+
+  my_dict <- tibble::tribble(
+    ~Variable, ~Description,
+    "age", "Age from Dictionary"
+  )
+
+  tbl <- labeled_data |>
+    gtsummary::tbl_summary(include = age) |>
+    add_auto_labels(dictionary = my_dict)
+
+  age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
+  expect_equal(age_label, "Age from Attribute")
+})
+
+test_that("prefer_dictionary: manual still wins over dictionary", {
+  skip_if_not_installed("gtsummary")
+  skip_if_not_installed("tibble")
+
+  old_opt <- getOption("sumExtras.prefer_dictionary")
+  on.exit(options(sumExtras.prefer_dictionary = old_opt), add = TRUE)
+  options(sumExtras.prefer_dictionary = TRUE)
+
+  labeled_data <- get_unlabeled_trial()
+  attr(labeled_data$age, "label") <- "Age from Attribute"
+
+  my_dict <- tibble::tribble(
+    ~Variable, ~Description,
+    "age", "Age from Dictionary",
+    "grade", "Grade from Dictionary"
+  )
+
+  tbl <- labeled_data |>
+    gtsummary::tbl_summary(
+      include = c(age, grade),
+      label = list(age ~ "Age Manual Override")
+    ) |>
+    add_auto_labels(dictionary = my_dict)
+
+  age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
+  grade_label <- tbl$table_body$label[tbl$table_body$variable == "grade"][1]
+
+  # manual > dictionary, even with prefer_dictionary
+  expect_equal(age_label, "Age Manual Override")
+  # dictionary wins (no manual, no attribute for grade)
+  expect_equal(grade_label, "Grade from Dictionary")
+})
+
+test_that("prefer_dictionary: three-way priority manual > dict > attr", {
+  skip_if_not_installed("gtsummary")
+  skip_if_not_installed("tibble")
+
+  old_opt <- getOption("sumExtras.prefer_dictionary")
+  on.exit(options(sumExtras.prefer_dictionary = old_opt), add = TRUE)
+  options(sumExtras.prefer_dictionary = TRUE)
+
+  labeled_data <- get_unlabeled_trial()
+  attr(labeled_data$age, "label") <- "Age from Attribute"
+  attr(labeled_data$marker, "label") <- "Marker from Attribute"
+
+  my_dict <- tibble::tribble(
+    ~Variable, ~Description,
+    "age", "Age from Dictionary",
+    "grade", "Grade from Dictionary"
+  )
+
+  tbl <- labeled_data |>
+    gtsummary::tbl_summary(
+      include = c(age, marker, grade),
+      label = list(age ~ "Age Manual")
+    ) |>
+    add_auto_labels(dictionary = my_dict)
+
+  age_label <- tbl$table_body$label[tbl$table_body$variable == "age"][1]
+  marker_label <- tbl$table_body$label[tbl$table_body$variable == "marker"][1]
+  grade_label <- tbl$table_body$label[tbl$table_body$variable == "grade"][1]
+
+  # age: manual wins
+  expect_equal(age_label, "Age Manual")
+  # marker: only attribute (no dict entry)
+  expect_equal(marker_label, "Marker from Attribute")
+  # grade: dictionary wins (no manual, no attribute)
+  expect_equal(grade_label, "Grade from Dictionary")
 })
 
 test_that("add_auto_labels() handles underscores in variable names", {
